@@ -1,12 +1,12 @@
 //! Used to instatiate websockets 
 
 mod callback_handle;
-mod exchange_ws;
-mod open_limit_ws;
+mod exchange_stream;
+mod open_limit_stream;
 mod subscriptions;
 
 pub use callback_handle::CallbackHandle;
-pub use exchange_ws::ExchangeWs;
-pub use open_limit_ws::OpenLimitsWs;
+pub use exchange_stream::ExchangeStream;
+pub use open_limit_stream::OpenLimitStream;
 pub use subscriptions::Subscriptions;
 pub use super::shared;
\ No newline at end of file
